pub enum Message {
Show 14 variants
ExcludeTags(ExcludeTags),
RemoveExcludeTags(RemoveExcludeTags),
IncludeTags(IncludeTags),
RemoveIncludeTags(RemoveIncludeTags),
ExcludeMatchingEntityIds(ExcludeRegexEntityIds),
RemoveExcludeMatchingEntityIds(RemoveExcludeRegexEntityIds),
IncludeMatchingEntityIds(IncludeRegexEntityIds),
RemoveIncludeMatchingEntityIds(RemoveIncludeRegexEntityIds),
ExcludeEntityIds(ExcludeEntityIds),
RemoveExcludeEntityIds(RemoveExcludeEntityIds),
IncludeEntityIds(IncludeEntityIds),
RemoveIncludeEntityIds(RemoveIncludeEntityIds),
IncludeTopics(IncludeTopics),
RemoveIncludeTopics(RemoveIncludeTopics),
}Expand description
Exclude criteria are evaluated first. If no matching exclude criteria the event is emitted. If an exclude criteria is matching the include criteria are evaluated. If no matching include criteria the event is discarded. If matching include criteria the event is emitted.
Variants
ExcludeTags(ExcludeTags)
RemoveExcludeTags(RemoveExcludeTags)
IncludeTags(IncludeTags)
RemoveIncludeTags(RemoveIncludeTags)
ExcludeMatchingEntityIds(ExcludeRegexEntityIds)
RemoveExcludeMatchingEntityIds(RemoveExcludeRegexEntityIds)
IncludeMatchingEntityIds(IncludeRegexEntityIds)
RemoveIncludeMatchingEntityIds(RemoveIncludeRegexEntityIds)
ExcludeEntityIds(ExcludeEntityIds)
RemoveExcludeEntityIds(RemoveExcludeEntityIds)
IncludeEntityIds(IncludeEntityIds)
RemoveIncludeEntityIds(RemoveIncludeEntityIds)
IncludeTopics(IncludeTopics)
RemoveIncludeTopics(RemoveIncludeTopics)
Implementations
sourceimpl Message
impl Message
sourcepub fn merge<B>(
field: &mut Option<Message>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>( field: &mut Option<Message>, tag: u32, wire_type: WireType, buf: &mut B, ctx: DecodeContext ) -> Result<(), DecodeError>where B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.